API docs for “spamfighter.plugin.IDefaultDomainProvider”

# Class s.p.IDefaultDomainProvider(INamedPlugin):

Part of spamfighter.plugin View Source View In Hierarchy

Интерфейс плагина, возвращающего ссылку на провайдер домена по умолчанию.

Method | getDefaultDomain | Получить домен по умолчанию в системе.

Inherited from INamedPlugin:

Method | name | Получить имя плагина.

def getDefaultDomain(): (source)
Получить домен по умолчанию в системе.

Returns | домен по умолчанию. (type: `spamfighter.interfaces.IDomain` )